# -*- coding: utf-8 -*-
"""
Created on Wed Mar 11 01:46:20 2026
@author: Nicolas Tharaud
          __  
    ___  |_|____ ___
  / __ \/ / ___/ __ \
 / / / / / |__| |_| |
/_/ /_/_/\___/\____/T
"""

"""
Nicopal Version Information
"""

__version__ = """\
Nicopal - version 0.3.1
Author : Nicolas Tharaud <n.tharaud6@gmail.com>
Copyright (c) 2026 Nicolas Tharaud
Colour palettes designed by a protanopic student
"""

def show_info():
    print(__version__)

if __name__ == "__main__":
    show_info()