# -*- coding: utf-8 -*-
"""
Created on Wed Mar 11 01:56:39 2026
@author: Nicolas Tharaud
          __  
    ___  |_|____ ___
  / __ \/ / ___/ __ \
 / / / / / |__| |_| |
/_/ /_/_/\___/\____/T
"""

class PaletteNotFoundError(Exception):
    """- Invalid Nicopal palette name"""
    pass