# -*- coding: utf-8 -*-
"""
Created on Thu Mar  5 10:46:13 2026
@author: Nicolas Tharaud
          __  
    ___  |_|____ ___
  / __ \/ / ___/ __ \
 / / / / / |__| |_| |
/_/ /_/_/\___/\____/T
"""

from .__version__ import __version__ 
from .palettes import pal_hex, pal, pal_list, pal_show # v0.1.0
from .palettes import pal_test # v0.3.0
from .palettes import pal_gallery, pal_all, pal_sample, pal_demo # v0.3.1